﻿using PropertyChanged;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace DataEntity
{
    [ImplementPropertyChanged]
    [Table("Materialy")]
    public partial class Material : BaseModel
    {
        [Key]
        [Column(Order=1)]
        public int MaterialID { get; set; }

        [Required (ErrorMessage ="Název materiálu je povinný.")]
        [StringLength(255)]
        public string NazevMat { get; set; }

        [Required(ErrorMessage = "Pojistné množství je povinný údaj.")]
        [Range (0, int.MaxValue, ErrorMessage = "Pojistné množství musí nezáporné.")]
        public int MnozPoj { get; set; }

        [Required(ErrorMessage = "Množství do palety je povinný údaj.")]
        [Range(1, int.MaxValue, ErrorMessage = "Množství do palety musí být kladné.")]
        public int MnozDoPal { get; set; }

        public string Komentar { get; set; }

        [Column (TypeName = "date")]
        public DateTime Datum { get; set; }

        public int MernaJednotkaId { get; set; }

        [ForeignKey("MernaJednotkaId")]
        public virtual MernaJednotka MernaJednotka { get; set; }


        public virtual ObservableCollection<Paleta> Palety { get; set; }


        public int CelkoveMnozstvi
        {
            get
            {
                if (Palety == null)
                {
                    return 0;
                }
                else
                {
                    return Palety.Sum(x => x.MnozPa);
                }
            }
        }


        //public int CelkoveMnozstvi => (Palety==null) ? 0 : Palety.Sum(x => x.MnozPa);

        public bool PodPojistnymMnozstvim
        {
            get
            {
                return CelkoveMnozstvi < MnozPoj;
            }
        }

        // public bool PodPojistnymMnozstvim => CelkoveMnozstvi < MnozPoj;


        //private int _moje;
        //public int Moje
        //{
        //    get
        //    {
        //        return _moje;
        //    }
        //    set
        //    {
        //        _moje = value;
        //        OnPropertyChganged(() => Moje);
        //        On...(() => Vek);
        //    }
        //}

    }
}
